package com.jz.dmp.modules.controller.sys;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.sys.bean.DmpPermissionBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpPermissionDto;
import com.jz.dmp.modules.controller.sys.bean.DmpPermissionRequest;
import com.jz.dmp.modules.model.DmpPermission;
import com.jz.dmp.modules.service.sys.DmpPermissionService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 资源表Controller
 * @author ybz
 *
 */
@RestController
@RequestMapping("/dmp/permission")
@Api(tags = "资源表")
public class DmpPermissionController {
	
	@Autowired
	private DmpPermissionService dmpPermissionService;
	
	/**根据父级资源编码，获取当前登录用户所有资源
	 * @param dmpPermissionRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/findListByParentCode")
	@ApiOperation(value = "获取当前用户指定资源", notes = "根据父级资源编码，获取当前登录用户所有资源")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "parentCode", value = "父资源编码"),
		@ApiImplicitParam(name = "type", value = "请求类型：0：用户项目下资源；1：用户系统级别资源")
	})
	public BaseBeanResponse<Map<String, Object>> findListByParentCode(@RequestParam(name = "parentCode", required = true) String parentCode, @RequestParam(name = "type", required = true) String type, HttpServletRequest httpRequest){
		BaseBeanResponse<Map<String, Object>> baseBeanResponse = new BaseBeanResponse<Map<String, Object>>();
		
		try {
			baseBeanResponse = dmpPermissionService.findUserAndPremissionByParentCode(parentCode, type, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("查询失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
}
